package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````\!L``#0```"4`0$```0`!30`(``)
M`"@`'0`<``$``'!@BP``8(L``&"+``#P````\`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!4C```5(P```4```````$`
M`0```)#]``"0_0$`D/T!`+@"``#,`@``!@```````0`"````F/T``)C]`0"8
M_0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DD/T`
M`)#]`0"0_0$`<`(``'`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`!1$7JJ^>X0#`T'64"G`!/DPNYH,$
M````$`````$```!'3E4```````,````"`````````&$```!N````````````
M``!;````10``````````````"```````````````.0```#P`````````3```
M`#L```!G`````````"P```!2````4P```#0```!B````:@````,````Q````
M```````````C````/P```$```````````````%0```!+````.````$\`````
M````;0```"$````'````"@`````````;`````````$,```!C````40```#4`
M````````3@```&4`````````#P```#T``````````````%P````S````2@``
M`$@`````````````````````````00`````````````````````````8````
M$0```"X```!"````(@```"<`````````*P````P```!)````.@```#X```!6
M````-P```#````!L````1````````````````````&8```!7`````````$8`
M``!9````*`````8````D````30``````````````````````````````````
M``````````````````0``````````````&0`````````````````````````
M```````````2`````````%@`````````````````````````````````````
M```````````````=`````````&@```!K`````````!\``````````````!P`
M````````:0``````````````````````````````$````"`````F````"0``
M``X````>````+0``````````````6@```!H```!0``````````````!5````
M)0```%X````O````%@```"H````9````#0``````````````70```#(````5
M````1P```%\````````````````````````````````````%````````````
M````````-@```````````````````!,````````````````````I````%P``
M`!0```````````````````````````````````!@``````````L`````````
M80``````````````$0```$\````(````"`````&0$`0E0`2`*(``!:"&4(2`
M`0``"R@$C#B@$D6*```(3P```%````!3````5P```%@```!@````80```&(`
M``!D````90```&<```!H````:0```&H```!M```````````````!KS3H;L7?
M'\[>1RUK?YI\+L6;MM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'
MPN4_+%COEWFZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-XYX5
MC"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````````````````````````
M``!$%@````````,`#``````````"```````#`!@`"0(`````````````$@``
M`-P``````````````!(````7`@`````````````2````>P(`````````````
M$@```%0"`````````````!(```"#```````````````2````T0``````````
M````$0```%4!`````````````!(```#H`@`````````````2````*`,`````
M````````$@```/(``````````````!(````!```````````````@````I`(`
M````````````$@```",!`````````````!(````3`0`````````````2````
M0`(`````````````$@````4!`````````````!(```#@`0`````````````2
M````$```````````````(````',!`````````````!(```"4`@``````````
M```2````X0``````````````$@```)0!`````````````!(```"R`0``````
M```````2````V@(`````````````$@```"P``````````````"````!&````
M```````````2````10$`````````````$@```&,``````````````!(```#`
M```````````````2````=```````````````$@```#D"`````````````!(`
M```"`@`````````````2````:0(`````````````$@```"T$````````````
M`!(```"D```````````````2````_`(`````````````$0```(T!````````
M`````!(````6`P`````````````1````1P(`````````````$@```,8!````
M`````````!(````W`0`````````````2````Z`$`````````````$@```(,"
M`````````````!(````K`@`````````````2````Y@``````````````$@``
M`*H!`````````````!(```!L`0`````````````2````\0$`````````````
M$@```%L"`````````````!(````R`@`````````````2````3@(`````````
M````$@```-("`````````````!(````$`P`````````````2````^P(`````
M````````(0```(\``````````````!(````D`@`````````````2````8`$`
M````````````$@```)L"`````````````!(```#Z`@`````````````1````
MC0(`````````````$0```'`"`````````````!(```"S```````````````1
M````JP(`````````````$@```'X!`````````````!$```#$`@``````````
M```2````V`$`````````````$@```"P!`````````````!(````/`@``````
M```````2````5```````````````$@```#\#`````````````!(````=`@``
M```````````2````X0(`````````````$@```-,!`````````````!(```"9
M`0`````````````2````M0(`````````````(@```)@$``!<``(``````!``
M&0`V!```<#D``(`````2``X`O00``!PP``"@!@``$@`.`/4"``!`&0``L`(`
M`!(`#@"=`P``8"D```0````2``X`RP,``+PV``"T`@``$@`.`%X$``!(``(`
M`````!``&0#C!```9"D``)0"```2``X`HP0``$@``@``````$``9`*X#``#X
M*P``,````!(`#@#A`P``9"X``(0````2``X`0@0``+Q)```$````$0`0`&P$
M``!<1@``.`$``!(`#@!W!```E"<``%P````2``X`?P0``%P``@``````$``9
M`+@$``!<``(``````!``&0#1!```#"\``!`!```2``X`400``````@``````
M$``8``4$```H+```9````!(`#@#*!```2``"```````0`!@`\`0``$0``@`$
M````$0`8`+L#``"<20``!````!(`#@!7!```\!L````````2``X`AP0``!1)
M``"(````$@`.`*\$``#\10``8````!(`#@!3!``````"```````@`!@`&P0`
M`.@N```D````$@`.`.\#``!L*```]````!(`#@`1!```E$<``(`!```2``X`
MEP0``%P``@``````$``9`/H$``",+```V`$``!(`#@``7U]G;6]N7W-T87)T
M7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;W!E;C8T`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`7U]S='!C<'E?
M8VAK`&5X:70`<W1R;F-M<`!S=')R8VAR`&-L;W-E9&ER`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I
M9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE
M;6-M<`!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E861D
M:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C
M97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I
M<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]A96%B:5]U;G=I;F1?
M8W!P7W!R,`!?7V%E86)I7W5N=VEN9%]C<'!?<'(Q`&QI8G!E<FPN<V\`;&EB
M<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`&QI
M8F=C8U]S+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L
M:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L
M96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN
M86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/
M7W-T9&EN7W5S960`7U]D871A7W-T87)T`%]?8G-S7W-T87)T7U\`<VAA7W5P
M9&%T90!X<U]I;FET`%]?96YD7U\`7U]L:6)C7V-S=5]I;FET`%]?8G-S7V5N
M9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E
M9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L
M`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1T-#7S,N-0`O=7-R+VQI8B]P97)L
M-2\U+C(V+C$O87)M=C=L+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%````````
M``(``0`"``(``@`!``$``0`"``,``0`!``(``0`!``(``0`"``$``0`"``(`
M!``$``(``0`!``$``0`!``$``@`"``(``@`!``(`!``%``(``@`!``(``@`"
M``$`!``"``(``@`"``(``@`"``(``0`"``$``@`"``(``@`!``(``0`"``(`
M`0`"``$``P`"``(``@`$``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0![`P``
M$````"`````4:6D-```%``<%`````````0`!`&$#```0````(````!1I:0T`
M``0`!P4````````!``$`CP,``!`````@````529Y"P```P`1!0````````$`
M`0!Q`P``$``````````4:6D-```"``<%````````D/T!`!<```"4_0$`%P``
M`,#_`0`7````X/\!`!<```#\_P$`%P````0``@`7````%``"`!<````8``(`
M%P```"```@`7````)``"`!<````H``(`%P```"P``@`7````,``"`!<````X
M``(`%P```#P``@`7````1``"`!<```#$_P$`%0D``,C_`0`5#0``S/\!`!4.
M``#0_P$`%14``-3_`0`5'```V/\!`!4>``#<_P$`%1\``.3_`0`5)P``Z/\!
M`!4I``#L_P$`%3\``/#_`0`500``]/\!`!5#``#X_P$`%4X``,S^`0`6`P``
MT/X!`!8$``#4_@$`%@4``-C^`0`6!@``W/X!`!8'``#@_@$`%@@``.3^`0`6
M"@``Z/X!`!8+``#L_@$`%@X``/#^`0`6#P``]/X!`!80``#X_@$`%A$``/S^
M`0`6$@```/\!`!83```$_P$`%A0```C_`0`6%@``#/\!`!87```0_P$`%A@`
M`!3_`0`6&0``&/\!`!8:```<_P$`%AL``"#_`0`6'0``)/\!`!8@```H_P$`
M%B$``"S_`0`6(@``,/\!`!8C```T_P$`%B0``#C_`0`6)0``//\!`!8F``!`
M_P$`%B@``$3_`0`6*@``2/\!`!8K``!,_P$`%BP``%#_`0`6+0``5/\!`!8N
M``!8_P$`%B\``%S_`0`6,```8/\!`!8Q``!D_P$`%C(``&C_`0`6,P``;/\!
M`!8T``!P_P$`%C4``'3_`0`6-@``>/\!`!8W``!\_P$`%C@``(#_`0`6.@``
MA/\!`!8[``"(_P$`%CP``(S_`0`6/0``D/\!`!9```"4_P$`%D(``)C_`0`6
M1```G/\!`!9%``"@_P$`%D8``*3_`0`61P``J/\!`!9(``"L_P$`%DH``+#_
M`0`62P``M/\!`!9,``"X_P$`%DT``+S_`0`63@``"$`MZ7X!`.L(@+WH!.`M
MY03@G^4.X(_@"/"^Y6#H`0``QH_B'LJ,XF#XO.4`QH_B'LJ,XECXO.4`QH_B
M'LJ,XE#XO.4`QH_B'LJ,XDCXO.4`QH_B'LJ,XD#XO.4`QH_B'LJ,XCCXO.4`
MQH_B'LJ,XC#XO.4`QH_B'LJ,XBCXO.4`QH_B'LJ,XB#XO.4`QH_B'LJ,XACX
MO.4`QH_B'LJ,XA#XO.4`QH_B'LJ,X@CXO.4`QH_B'LJ,X@#XO.4`QH_B'LJ,
MXOCWO.4`QH_B'LJ,XO#WO.4`QH_B'LJ,XNCWO.4`QH_B'LJ,XN#WO.4`QH_B
M'LJ,XMCWO.4`QH_B'LJ,XM#WO.4`QH_B'LJ,XLCWO.4`QH_B'LJ,XL#WO.4`
MQH_B'LJ,XKCWO.4`QH_B'LJ,XK#WO.4`QH_B'LJ,XJCWO.4`QH_B'LJ,XJ#W
MO.4`QH_B'LJ,XICWO.4`QH_B'LJ,XI#WO.4`QH_B'LJ,XHCWO.4`QH_B'LJ,
MXH#WO.4`QH_B'LJ,XGCWO.4`QH_B'LJ,XG#WO.4`QH_B'LJ,XFCWO.4`QH_B
M'LJ,XF#WO.4`QH_B'LJ,XECWO.4`QH_B'LJ,XE#WO.4`QH_B'LJ,XDCWO.4`
MQH_B'LJ,XD#WO.4`QH_B'LJ,XCCWO.4`QH_B'LJ,XC#WO.4`QH_B'LJ,XBCW
MO.4`QH_B'LJ,XB#WO.4`QH_B'LJ,XACWO.4`QH_B'LJ,XA#WO.4`QH_B'LJ,
MX@CWO.4`QH_B'LJ,X@#WO.4`QH_B'LJ,XOCVO.4`QH_B'LJ,XO#VO.4`QH_B
M'LJ,XNCVO.4`QH_B'LJ,XN#VO.4`QH_B'LJ,XMCVO.4`QH_B'LJ,XM#VO.4`
MQH_B'LJ,XLCVO.4`QH_B'LJ,XL#VO.4`QH_B'LJ,XKCVO.4`QH_B'LJ,XK#V
MO.4`QH_B'LJ,XJCVO.4`QH_B'LJ,XJ#VO.4`QH_B'LJ,XICVO.4`QH_B'LJ,
MXI#VO.4`QH_B'LJ,XHCVO.4`QH_B'LJ,XH#VO.7T06WA6$*?Y5@RG^7X8,WA
M$."-Y2303>($0(_@#""-Y0P@C>(0$(WE$!"-XA0`C>4#4)3G%`"-X@`PE>4<
M,(WEW/__ZR`BG^4@,I_E`B"4YP,`E.<"$*#A``P`ZQ`RG^4#,)3G`'#3Y0``
M5^-6```*`#*?Y0-@E.<``);E8?__Z^XST.4`(*#A``"6Y0(P@^/N,\+E6___
MZQ1@G>7N,]#E!""&X@-@AN(!,(/C!P%RX^XSP.5:``"*`@&@X:7__^NT(9_E
MM!&?Y1`PG>44X)WE`B"/X`$0C^``0)'E!`""Y9P1G^4!`%[CF"&?Y1#@H-,`
MP)/E`1"/X`(@C^``P(#E$@"`Z0P@@.4(``#:#B&#X`P0@.($,(/B!,"3Y`(`
M4^$$P*'E^___&@/@CN(.X:#A`!"@XU!!G^4&(*#A`#"@X0`0C>4.$(#G0!&?
MY01`C^`,`)3E`1"/X`/__^L`8%#B*P``"BA!G^48<(WB!$"/X`P`E.5*___K
M&`&?Y0<0H.$``(_@K0``ZP``4.,;```*!#&?Y0,PC^`,`)/EX_[_ZQ[__^L<
M()WE!@"@X0`PE>4#`%+A)P``&B30C>+00,WAV&#-X1#0C>($\)WD`?__Z\@P
MG^4``%#C`S"/X`P`@^4=```*$___ZX@PG^4#8)3G``"6Y0/__^M5=L#EG?__
MZ@@`E.4``%#C"@``"H<'`.O>___J#`"4Y=_^_^L`8*#AS___ZG@PG^5X`)_E
M`Q"4YP``C^!!___K;`"?Y0<0H.$``(_@?0``ZP``4.,(`(3ESO__"NS__^HF
M___K`0"@XUW__^M@Y0$`*`$```@!```<`0``,`$```0!```TY@$`*.8!`)0R
M``"4,@``N.4!`%0-``"8Y0$`U"\``'#E`0`LY0$`-`$``)@P``"P+@```+"@
MXP#@H.,$$)WD#2"@X00@+>4$`"WE**"?Y20PC^(#H(K@(,"?Y0S`FN<$P"WE
M&#"?Y0,PFN<4`)_E``":YZ#^_^N0_O_KB.(!```!```@`0``/`$``!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`9?^_^IHX@$`#`$``#``G^4P,)_E,""?Y0``
MC^`#,(_@``!3X0(@C^`$```*'#"?Y0,PDN<``%/C````"A/_+^$>_R_AR.,!
M`,3C`0`TX@$`$`$``#P`G^4\,)_E/""?Y0``C^`#,(_@`!!#X`(@C^!!$:#A
MH1^!X,$0L.$$```*'#"?Y0,PDN<``%/C````"A/_+^$>_R_A@.,!`'SC`0#L
MX0$`%`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q%$,)_E"$`MY03@
MC>4#,)+G``!3XP(```HP,)_E`P"?Y_K^_^O'___K)#"?Y0$@H.,`0)WE!-"-
MX@,PC^``(,/E!/"=Y##C`0"@X0$`.`$``+SB`0#DX@$`S/__ZO`PG^7P0FWA
M^&#-X0!P4.+P@<WA&*"-Y1S@C>4#,(_@,```"M`@G^4",)/G`)"3Y0``6>,M
M```*`##7Y3U04^(!4*`3``!3XP!0H`,``%7C%P``&@!`F>4``%3C#0``"@&`
MH.$)8*#A!2"@X0<0H.$$`*#AMO[_ZP``4.,"```:!3#4YST`4^,0```*!$"V
MY0``5./S__\:!`"@X=!`S>'88,WAT('-X1B@G>4<T(WB!/"=Y`=0H.$!,/7E
M``!3XST`4Q/[__\:!U!%X.#__^H)8$;@`5"%XD9AH.$%0(3@`&"(Y>O__^H'
M0*#AZ?__Z@E`H.'G___J'.$!`"0!``#T06WAG#"?Y0!0H.'X8,WAE'"?Y1#@
MC>4,T$WB#4"@X0=PC^`#8)?G`#"6Y00PC>4$$*#A!0"@X;#__^L``%#C#@``
M"F0PG^4`$)WE`S"7YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E
M``!2XP0@@^3[__\:Z___Z@0@G>4`,);E`P!2X00``!H,T(WBT$#-X=A@S>$0
MT(WB!/"=Y$/^_^LH`0``&.`!`"0!``#T0FWA-#*?Y0%`H.'X8,WA`%"@X?"!
MS>$DDI_E^*'-X2#@C>4`(-'E%-!-X@F0C^`#8)GG/0!2XP%`@0($`*#A`#"6
MY0PPC>4`_O_K`'"@X0@0C>(%`*#A>___ZP"`4.)#```*^?W_ZP<`4.$Z```J
MT#&?Y0B`G>4#D)GG"(&@X0`PU>4]`%/B`0"@$P``4^,``*`#``!0XP4```H%
M`*#A`3#PY0``4^,]`%,3^___&@4`0.`"<(?B`*"9Y0``A^`,_O_K``!0XP@`
MBN=8```*`""9Y0$0A>((`)WE`##5Y0`!DN<]`%/C``!3$P`PP.4&```*`2"`
MX@$PT>0"`*#A``!3XST`4Q,!,,+D^?__&CTPH.,`(*#A`##`Y0$PU.0``%/C
M`3#BY?O__QH``*#C#""=Y0`PEN4#`%+A/@``&A30C>+00,WAV&#-X="!S>'8
MH<WA(-"-X@3PG>0!,$CB`2#4Y```4N,!(./E^___&NW__^K,,)_E`Y"9YP"P
MF>4`H)OE``!:XP@0H`,)```*"#"@X0L@H.$```#J"C"@X000LN4!H(/B``!1
MX_K__QH#,(/B`Q&@X8PPG^4#,(_@`""3Y0``4N,1```:`2"@XP$`H.$`((/E
MQOW_ZP`P4.($,(WE$@``"@J!H.$+$*#A"""@X<[]_^L$,)WE`#")Y0$@BN(`
M$*#C`A&#YPB@C>6:___J"P"@X>;]_^L``%#C`#"@X0``B>4!```*"H&@X?+_
M_^H``.#CO/__ZK#]_^LH`0``6-\!`"0!``!4WP$`8#&?Y?1";>%<(9_E^&#-
MX0!@4.+P@<WA^*'-X0,PC^`@X(WE?-!-X@)`D^<`,)3E=#"-Y0(```H`,-;E
M``!3XPH``!IT()WE`#"4Y0,`4N%#```:?-"-XM!`S>'88,WAT('-X=BAS>$@
MT(WB!/"=Y"/]_^L`<%#B\?__"NR`G^7LD)_E[*"?Y0B`C^`)D(_@"J"/X`<`
MH.&F_?_K``!0XR@```H34(#B"!"@X04`H.&U_?_K``!0X_7__PH)$*#A!0"@
MX;#]_^L``%#C\/__"@8`H.%)_?_K`+"@X04`H.%&_?_K``"+X`(`@.)M_?_K
M`+"@X0HPH.$`8(WE`"#@XP$0H.,$4(WEC?W_ZPL0H.$(((WB`P"@XU;]_^L!
M`'#C"P"@X0,```H8,)WE#SH#X@$)4^,(```*,_W_ZPL`H.$9_?_KTO__Z@<`
MH.%&_?_K!@"@X5_]_^NY___JI___Z_7__^I2_?_K&-T!`"@!``#`)P``P"<`
M`,`G``",,)_E_$!MX0`0H.&$P)_E"."-Y7303>(`4*#A#2"@X0,`H.,#,(_@
M#$"3YP`PE.5L,(WE7?W_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,'
M```*;""=Y0`PE.4#`%+A"0``&G30C>+00,WA"-"-X@3PG>0%`*#A`A"@X_/\
M_^L0#V_AH`*@X?'__^HH_?_KE-L!`"@!``#P0FWA'$&?Y?\O`.,8,9_E^&#-
MX0!PH.'P@<WA#`&?Y0&`H.$8H(WE!$"/X!S@C>4!VDWB`Z"4YPC03>(!RHWB
M!&"-X@3`C.(&$*#A``"/X``PFN4`,(SE*OW_ZP``4.,K``#:"%"-X@&00.+`
M,)_E"5"%X`0@5>4#,)3G``!2XP!`D^4:```*`)"@X0D@H.$O$*#C!@"@X3+]
M_^L``%#C%0``"@0`H.&__/_K"3"@X08@H.$'$*#AUOS_ZP$ZC>($,(/B`""3
MY0`PFN4#`%+A$P``&@':C>((T(WBT$#-X=A@S>'0@<WA&*"=Y1S0C>($\)WD
M``!9X^/__QH$`*#AJ?S_ZP@@H.$'$*#AE/S_Z^G__^H8,)_E`S"4YP!`D^7U
M___JW/S_Z_3:`0`H`0``]"4```0!```,,9_E_$!MX0`0H.$$P9_E"."-Y0':
M3>(,T$WB`2J@XP1`C>(#,(_@!`"@X0Q0D^<!RHWB!,",X@`PE>4`,(SEK_S_
MZP0`0.`!`$#B`#"$X`0`4^$*``":`"#4YR\`4N,'```:`!"@XP(``.H`(-/E
M+P!2XP(``!H!$$/D!`!3X?G__QHO$*#C!`"@X6G\_^L``%#C#P``"@0`4.$`
M,*"#`##`A00`H.&A_/_K`3J-X@0P@^(`()/E`#"5Y0,`4N$2```:`=J-X@S0
MC>+00,WA"-"-X@3PG>0!.HWB!#"#X@`@D^4`,)7E`P!2X0<``!HD`)_E``"/
MX`':C>(,T(WBT$#-X0C@G>4,T(WBB/S_ZI/\_^O`V0$`*`$```0D``",$9_E
M]$)MX0`@H..$P9_E^&#-X0`PH./P@<WA`'"@X_BAS>$`H*#A`1"/X"#@C>4!
MV$WB#!"1YQS03>("X*#C`<B-X@#@C>44P(SB`9"@X0`0D>4`$(SE<_S_ZP%`
M4.(`4,'BQ6^@X08`H.'&'Z#A!F`DX``@5N`!,"?@<F#_Y@`@)N``(%+@`3##
MX`)`5.`#4,7@``!4XP`PU>(X``"Z!7"@X?!0G^4(L*#C!&"@X0&P0.,,0(WB
M!5"/X``0H.,&(*#A!S"@X0H`H.$`$(WE5?S_ZPL@H.$$$*#A"@"@X1C\_^L'
M`%#C'0``F@@`0.(`@)3@`P``.AD``.H!@$CB!`!8X18``#H((*#C!1"@X0@`
MH.'A^__K``!0X_;__QH$0$C@!`"6X,0?I^`!.(WB%#"#X@`@D^4`,)GE`P!2
MX1(``!H!V(WB'-"-XM!`S>'88,WAT('-X=BAS>$@T(WB!/"=Y`%H5N(`(*#C
M`'#'X@`PX./_+T_C`P!7X0(`5@'-__\:``#@XP`0X./F___J*_S_ZYS8`0`H
M`0``5-D!``A`+>4\0)_E/#"?Y03@C>4$0(_@`S"4YP``D^7D^__K*""?Y2@P
MG^4H$)_E!."=Y0(@E.<#,(_@`$"=Y0C0C>(!$(_@0/S_ZA37`0`$`0``&`$`
M`/`A```8(@``8#"?Y0A`+>5<()_E!."-Y0C03>(#,(_@`D"3YP``E.7,^__K
MWO__ZP``E.7)^__K`!"@XS0PG^4T()_E!!"-Y3`0G^4#,(_@`B"/X``PC>4!
M$(_@R/O_ZPC0C>(`0)WE!-"-X@3PG>2TU@$`!`$``)`D``!\#@``R"$``-PP
MG^7T06WAV""?Y?A@S>$0X(WE`MI-XAS03>(#,(_@#$"-X@)0D^<"*HWB`6J-
MXA0@@N(08(;B`#"5Y0`P@N7V^__KH,"?Y0$@`>,!$*#CF#"?Y0S`C^`#,(_@
M`1"-Z`0`H.'\^__K!`"@X080H.$!*J#C[_O_ZP!`4.(5``"Z`0"$XLW[_^L`
M<%#B!```"@80H.$$(*#AI/O_ZP`PH.,$,,?G`CJ-X@<`H.$4,(/B`""3Y0`P
ME>4#`%+A!P``&@+:C>(<T(WBT$#-X=A@S>$0T(WB!/"=Y`!PH./P___JN?O_
MZS#6`0`H`0``;"$``%PA``#!___J8#*?Y?1";>$`0*#A6"*?Y?A@S>$!8*#A
M\('-X4P"G^7XH<WA`S"/X"#@C>5"W4WB`I"3YPS03>)"+8WB&("-X@0@@N((
M$*#A``"/X``PF>4`,(+E\/S_ZP!0H.$O$*#C!`"@X4#[_^L``%#C$@``"OP!
MG^4$$*#A``"/X%/]_^L$`*#A0CV-X@0P@^(`()/E`#"9Y0,`4N%Q```:0MV-
MX@S0C>+00,WAV&#-X="!S>'8H<WA(-"-X@3PG>0&`*#A=_O_ZZP1G^4!$(_@
MAOO_ZP!@4.+E__\*G#&?Y9RQG^6<H9_E`S"/X`NPC^`4,(WE`##6Y0J@C^``
M`%/C/P``"@``5>,$```*!A"@X04`H.&E^__K``!0XR\```H&`*#A/OO_ZP$@
M0.(`<*#A`C"&X`,`5N$-```J`B#6YR\`4N,*```:`!"@XP(``.H`(-/E+P!2
MXP(``!H!$$/D`P!6X?G__QH&`*#A+/O_ZP!PH.$$`*#A*?O_ZP<`@.`!`(#B
M`0I0X[G__RKXP)_E"C"@X0$JH.,!$*#C"$"-Y8APC>(,P(_@0!"-Z(1@C>(&
M`*#A:_O_ZP@@H.$&$*#A`P"@XS3[_^L``%#C`P``&F`P%^4/.@/B`@E3XQ(`
M``JH$)_E``"@XP$0C^`_^__K`&!0XI[__PH`,-;E``!3X[___QH``%7C$P``
M"@L0H.$%`*#A9?O_ZP``4.,!<*`3"V"@$>W__PK1___J`1"@XP8`H.'N^O_K
M``!0X^?__QI,`)_E!A"@X0``C^#@_/_K!@"@X1/[_^N*___J`7"@XQ1@G>7"
M___J&OO_ZS#5`0`H`0``A"```&`@```@(```A!\``(`?``#X'P``5!\```0?
M``"4'@``"$`MY2\0H.,`0*#A!."-Y;_Z_^L``%#C!."=Y0%`@!($`*#A`$"=
MY0C0C>+W^O_J`#!0X@X```H`(-/E``!2XPL```H(0"WE`T"@X03@C>7-^O_K
M`0"`X@$*4.,'``"*!`"@X0!`G>4$X)WE"-"-XAG^_^H4`)_E``"/X./Z_^H`
M0)WE!-"-X@``H.,$\)WD7!T``'@AG^7P06WA=#&?Y0A@C>4,X(WE;`&?Y0C0
M3>)H89_E#4"@X0(@C^`#4)+G``"/X`9@C^``,)7E!#"-Y6S\_^M(`9_E``"/
MX&G\_^M``9_E``"/X&;\_^LX`9_E``"/X&/\_^LP`9_E``"/X&#\_^LH`9_E
M``"/X%W\_^L@`9_E``"/X%K\_^L8`9_E``"/X%?\_^L&`*#A5?S_ZP@!G^4`
M`(_@4OS_ZP`!G^4``(_@3_S_Z_@`G^4$$*#A``"/X`O\_^L`$%#B`0``"@8`
MH.%T_/_KW`"?Y000H.$``(_@`_S_ZP`04.("```*R`"?Y0``C^!K_/_KP`"?
MY000H.$``(_@^OO_ZP`04.(0```*K`"?Y0``C^!B_/_KI!"?Y:0`G^4!$(_@
M``"/X%W\_^L$()WE`#"5Y0,`4N$.```:"-"-XM!`S>$(8)WE#-"-X@3PG>1T
M`)_E!!"@X0``C^#C^__K`!!0XNO__PI@`)_E``"/X$O\_^OG___JBOK_ZPC2
M`0`H`0``I!T``/`=``"8'0``E!T``)0=``"0'0``E!T``"0=``"('0``C!T`
M``0=``!\'0``<!T``'`=``!L'0``D!P``&P=``#0'```(!T``*0<``!P,)_E
M"$`MY6P@G^4$X(WE"-!-XF0`G^4-$*#A`S"/X`)`D^<``(_@`#"4Y00PC>6Y
M^__K``!0XP4```H``-#E``!0XS``4!,!`*`#``"@$P$`(.($()WE`#"4Y0,`
M4N$#```:"-"-X@!`G>4$T(WB!/"=Y%;Z_^LXT`$`*`$``!@<```(0"WE!."-
MY0OZ_^LK^O_K``!0XP!`G>4$T(WB``"0%03PG>3P,)_E^$%MX0!0H.'H()_E
M^&#-X1"`C>7@8)_E%."-Y1C03>(#,(_@$!"-X@)`D^<&8(_@!@"@X0`PE.44
M,(WEB_O_ZP!P4.(%$*#A&P``"@`PU^4``%/C&```"A?Z_^L``%#C&```&@4`
MH.$!^O_K`("@X0<`H.'^^?_K``"(X`(`@.(E^O_K=,"?Y0"`H.$`(.#C;#"?
MY0$0H.,(<(WE#,"/X`,PC^`@$(WH0OK_ZP@0H.$&`*#AVOO_ZP(``.I$`)_E
M``"/X-;[_^L4()WE`#"4Y0,`4N$%```:&-"-XM!`S>'88,WA$("=Y130C>($
M\)WD#/K_ZXC/`0`H`0``Y!L``*`:``"@&@``4!L``/1";>$D-I_E),:?Y?A@
MS>'XH<WA'*:?Y?"!S>$@X(WE]-!-X@S`C^"@0(WB"J"/X!@`C>644(WB`P":
MYXB`C>(@8(WB%'"<Y=`BS.$`X)#E'`"-Y=@"S.$(<(CE^"#$X=P@S.'P`<3A
M.`"<Y080H.'X*,WAV"',X>S@C>4(`(7EM`6?Y?`JS>'0(\SA``"/X/0IS>$R
M^__K`'!0X@(```H`,-?E``!3XX8``!J&___K`'!0XH@```H'`*#AJ?G_ZX``
MH.$!`(#BT/G_ZP`PU^4`L*#A``!3XPP```I<E9_E"U"@X0F0C^`%`*#A`#"-
MY0`@X.,),*#A`1"@X^KY_^L!,/?E`E"%X@``4^/U__\:H`"=Y0``4.,#```:
M$```Z@0`M.4``%#C#0``"@80H.$+^__K`%!0XOC__PH`,-7E``!3X_7__PIE
M_/_K``!0X_+__PH%`*#AH_G_ZP"04.(7```:`%"@X_`PC>(%,8/@:$`3Y0``
M5.,*```*`##4Y0``4^,'```*!`"@X0%0A>)3_/_K``!0XP0``!H%09CG``!4
MX_3__QH`D*#C!```Z@0`H.&,^?_K``!0X^G__PH`D*#A"0"@X6;Y_^L`0*#A
M"P"@X6/Y_^L`0(3@`4N$X@1`A.($`*#AB/G_ZU#DG^4`<*#A`"#@XTC$G^4!
M$*#C#+"-Y4`TG^4.X(_@#,"/X`,PC^``4HWHH_G_ZP<`H.$'':#C!_G_ZP$`
M<.,#```:M?G_ZP`@D.41`%+C[0``&@8@H.$'$*#A`P"@XY#Y_^L`4%#B`P``
M&C`PG>4/.@/B`0E3XS0```K@(Y_E`1"@XP!`H.,8,)WE`@":Y]`CG^4`,)/E
M`'"-Y0``D.4"((_@9/G_ZQPPG>4$`*#A[""=Y0`PD^4#`%+AWP``&O30C>+0
M0,WAV&#-X="!S>'8H<WA(-"-X@3PG>0(___K!P"@X47Y_^L`0*#A[?__Z@>0
MH.$)`97G``!0XPP```H&$*#A`9")XIKZ_^L`,%#B]___"@`PT^4``%/C]/__
M"C;Y_^L``%#C\?__"@!PH.%E___J,'.?Y0T`H.,X^?_K`+"@X5,PH.,'<(_@
M9___ZCB`G>7P^/_K``!8X<;__QHP,)WE4S#HYP<-4^/"__\:!`"@X2KY_^L`
M0*#A[`*?Y080H.$``(_@>OK_ZP`04.)6```*&#"=Y0``D^5N_?_K`(!0XE$`
M``H(`*#A\OC_ZP,`4.,`8*#A#```FK`2G^4$`$#B``"(X`$0C^!-^?_K``!0
MXP4``!H$`%;C>@``"@9@B.`%,%;E+P!3XW8```J9_O_K`&!0X@0``!H(`*#A
M!A"@X>OX_^L`H%#B.@``&F`2G^5@`I_E8**?Y6"2G^4!$(_@7(*?Y0``C^"^
M^O_K$_G_ZU#BG^4(`(WE`"#@XTC"G^4!$*#C!`"@X4`RG^4*H(_@"9"/X`B`
MC^`.X(_@#,"/X`,PC^"`$(WH#."-Y1+Y_^L.``#J*/G_ZP`PD.41`%/C$```
M&@%0A>+\^/_K!B"@X0HPH.&``8WH"`"-Y0$0H.,$`*#A#%"-Y1"0C>4"^?_K
M!QV@XP0`H.%F^/_K`0!PXP!@H.'J__\*!P"@X93X_^N\`9_E!!"@X0``C^"1
M^O_K!`"@X87^_^MM___J&#"=Y0"`D^6J___J.OS_ZP``4.,`@*#A`##1X@&0
MH.&^__^Z"B!0XKBPC>(`8(WE`##!X@H`H.&Z^/_K"Q"@X08@H.,*`*#A??C_
MZU@QG^6X$)WE`S"/X`P@D^4,,(/B`@!1X:W__QJT(-OAM##3X0,`4N&I__\:
M,B!8XL!0C>(`8(WE`##)X@H`H.&E^/_K!1"@X0H`H.$H(*#C:/C_ZPCAG^4`
M(.#C`1"@XP#!G^4$`*#A"%"-Y?@PG^7H8,WE#N"/X`S`C^`#,(_@@!"-Z`S@
MC>6]^/_KO___ZA@PG>4$8)/E``!6XX3__PH&`*#A9?C_ZP,`4..`__^:N!"?
MY00`0.(``(;@`1"/X,'X_^L``%#C!H"@`7C__^H8,)WE`1"@XP!`H.-$`)_E
M`#"3Y0``FN<`<(WE!""-Y7P@G^4``)#E`B"/X'_X_^L9___J>OC_ZR@!``#`
MSP$`<,X!`(@9```X&@``*!D``#`8```4&0``+`$``.@8``#@%P``6!@``!P8
M``#T%@``<!8``,07``!H&```^!4``&`8``#P%0``H!<``$P5``!L%```#!<`
M`)P4```\%@``]!4``!@5``!L(I_E^$%MX6@2G^7X8,WA$("-Y6`RG^44X(WE
M"-!-X@(@C^`-4*#A`6"2YP`0EN4$$(WE`T"2YP``E.42^/_K`'"@X0``E.4/
M^/_K9##7Y040H.%E,,#E(`*?Y0``C^"7^?_K``!0XP(```H`,-#E,0!3XV$`
M``I4_?_K``"4Y0'X_^OX$9_E`S"@XP$@H.,!$(_@Y/?_ZP!P4.(+```*``"4
MY?CW_^L,,)?EU"&?Y0`0D^4"((_@X??_ZPPPE^4`,)/E"#"3Y0$%$^-8```:
M``"4Y>SW_^NL$9_E`S"@XP$@H.,!$(_@S_?_ZP!P4.(+```*E`&?Y040H.$`
M`(_@;_G_ZP"`4.(``)3E/P``"MWW_^L,,)?E"""@X0`0D^7']__K``"4Y=?W
M_^L`<*#A``"4Y=3W_^M4$9_E`2"@XP$0C^"F]__K2"&?Y0`0H.$'`*#A`B"/
MX+GW_^L``)3ER??_ZP`PH.$L`9_E`""@XP40H.$D49_E92##Y0``C^!/^?_K
M!5"/X```4.,`0*#A"`"%Y1````H'':#C!`"@X8#W_^L!,(#B$0!0XP$`4Q,F
M``"*!""=Y0`PEN4#`%+A(0``&@C0C>+00,WAV&#-X1"`G>44T(WB!/"=Y`0`
ME>7>_?_K``!0XP!`H.$(`(7EZ/__&J@`G^4``(_@\/?_ZP$PT.4``%/CF___
M"IG__^J=]__KC#"?Y0P@E^4#,(_@!#"3Y0``DN4`$)/EJ_K_Z[O__^H``)3E
MD_?_ZPPPE^4`$)/EP_?_ZZ#__^K*]__K5!"?Y0`PH.$$(*#A3`"?Y0$0C^`$
M$)'E``"/X``0D>73]__KW,<!`"@!```$`0``;!,``.04``#$%```G!0``(02
M``!$%```2!0``/@1```$R`$`K!,``&S'`0`HQP$`8!,``/!!;>$`0*#A"&"-
MY0S@C>6H_/_KF_S_ZP!0H.$T_?_K``!0XP``5!,#```:T$#-X0A@G>4,T(WB
M!/"=Y``PU.4``%/C^/__"BP0G^4%`*#A!""@XP$0C^#!]__K``!0X_'__QH$
M`*#AT$#-X0A@G>4,X)WE$-"-XN7Y_^J($0``_#N?Y?1";>$<((#B]$N?Y?A@
MS>%<P(#B\('-X?BAS>$#,(_@(."-Y57?3>($,)/G"."-X@X0H.$$,(WE`#"3
MY4PQC>4$,)+D,S^_Y@(`7.$$,*'E^O__&D)/C>(.(*#A!!"^Y23`DN4X,)+E
M#""2Y00`7N$,,"/@`C`CX`$P(^#C/Z#A0#".Y?/__QH`@)#EF1D'XZ$K#N/4
M8,#A@AI%X]DN1N,,4)#EW#P+XQ#@G>4;/TCC#,"=Y69!H.$0H)#E!9`GX`2P
M)^`!X([@"+`+X`'`C.`%X([@![`KX`K`C.`.L(O@%."=Y6BAH.$&D`G@Z,V,
MX`60*>`)P(S@"I`DX`R0">`!X([@!)`IX`?@CN`.D(G@&."=Y>R]B^!LP:#A
MZYV)X`'@CN`$0([@#.`JX`O@#N!KL:#A"N`NX`1`CN`<X)WEZ4V$X`'@CN`*
MH([@"^`LX`G@#N!ID:#A#.`NX`K@CN`@H)WEY.V.X`&@BN`,H(K@"<`KX`3`
M#.!D0:#A"\`LX`K`C.`DH)WE[LV,X`&@BN`+H(K@!+`IX`ZP"^!NX:#A";`K
MX`JPB^`HH)WE[+V+X`&@BN`)H(K@#I`DX`R0">!LP:#A!)`IX`J0B>`LH)WE
MZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`DX`I`A.`PH)WEZ4V$X`&@BN`.
MH(K@"^`LX`G@#N!ID:#A#.`NX`K@CN`TH)WEY.V.X`&@BN`,H(K@"<`KX`3`
M#.!D0:#A"\`LX`K`C.`XH)WE[LV,X`&@BN`+H(K@!+`IX`ZP"^!NX:#A";`K
MX`JPB^`\H)WE[+V+X`&@BN`)H(K@#I`DX`R0">!LP:#A!)`IX`J0B>!`H)WE
MZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`DX`I`A.!$H)WEZ4V$X`&@BN`.
MH(K@"^`LX`G@#N!ID:#A#.`NX`K@CN!(H)WEY.V.X`&@BN`,H(K@"<`KX`3`
M#.!D0:#A"\`LX`K`C.!,H)WE[LV,X`&@BN`+L(K@!*`IX`Z@"N!NX:#A":`J
MX`NPBN!0H)WE[+V+X`&@BN`)H(K@#I`DX`R0">!LP:#A!)`IX`J0B>!4H)WE
MZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`DX`J@A.!80)WE`4"$X.D=BN!@
MH)WE#D"$X`O@+.`)X`[@:9&@X0S@+N`$X([@7$"=Y>'MCN`"0(3@#,"$X`E`
M*^`!0"3@81&@X03`C.`"0(K@[JV,X`'`*>`.P"S@"T"$X`Q`A.!DP)WE;K&@
MX>I-A.`+X"'@"N`NX`+`C.`)P(S@:I&@X0[@C.!HP)WE":`KX.3MCN`$H"K@
M9$&@X0+`C.`!$(S@;,"=Y0H0@>`$H"G@#J`JX.X=@>!NX:#A`L",X`O`C.`.
ML"3@"L",X'"@G>4!L"O@X<V,X&$1H.$"H(K@":"*X'20G>4+H(K@[*V*X`*0
MB>`$0(G@`9`NX`R0*>!LP:#A"9"$X'A`G>7JG8G@`K"$X`Y`B^`,X"'@"N`N
MX&JQH.$.0(3@?."=Y8"@G>7I383@`N".X`$0CN`+X"S@">`NX&F1H.$.X('@
M`A"*X`F@*^`,$('@A,"=Y>3MCN`$H"K@9$&@X0H0@>#N'8'@!*`IX`+`C.`.
MH"K@"\",X&[AH.$*P(S@B*"=Y0ZP).#AS8S@`;`KX&$1H.$"H(K@":"*X(R0
MG>4+L(K@[+V+X`*0B>`$0(G@`9`NX`R0*>!LP:#A"9"$X)!`G>7KG8G@`J"$
MX`Y`BN`,X"'@"^`NX&NAH.&8L)WE#D"$X)3@G>7I383@`N".X`$0CN`*X"S@
M">`NX&F1H.$.$('@Y.V!X`(0B^`,$('@G,"=Y0FP*N`$L"O@9$&@X0NP@>`"
MP(S@!!`IX`X0(>`*P(S@`<",X*`0G>7NO8O@;N&@X>O-C.`.H"3@`A"!X`N@
M*N`)D('@I!"=Y6NQH.$*D(G@J*"=Y>R=B>`"$('@!!"!X`M`+N`,0"3@;,&@
MX0(@BN`.((+@#.`KX`G@+N`$$('@#B""X*S@G>5I0:#AZ1V!X`20C.$!D`G@
MX2V"X`/@CN`+L([@!.`,X`[@B>&PD)WE81&@X0O@CN"TL)WE`:"$X>+MCN`"
MH`K@`Y")X&(AH.$,D(G@`<`$X`.PB^`,P(KAN*"=Y02PB^`)0(S@;I&@X0+`
M@>'N383@#L`,X`+@`>`.X(SA"<""X0O@CN`$P`S@`["*X`F@`N`!L(O@"L",
MX;P0G>4+P(S@P+"=Y>3MCN!D0:#A[LV,X`2@B>$#$('@#J`*X`(@@>!NX:#A
M!!`)X`.PB^`!$(KA";"+X,20G>4"$('@#B"$X>P=@>`,(`+@;,&@X0Z@!.`#
MD(G@"B""X0R@CN$$0(G@`:`*X`R0#N`+((+@S+"=Y0F@BN'A+8+@!*"*X,A`
MG>5A$:#AXJV*X`&0C.$#L(O@`T"$X`*0">`.0(3@8B&@X0'@#.`.X(GA#+"+
MX`1`CN`"P('A:I&@X>I-A.`"X`'@#*`*X`[@BN'0H)WE"<""X0O@CN`$P`S@
MY.V.X&1!H.$#L(K@":`"X`&PB^`*P(SAU!"=Y0O`C.#8L)WE!*")X>[-C.`.
MH`K@;N&@X0,0@>`"(('@`["+X`00">`)L(O@W)"=Y0$0BN$.H`3@`A"!X`X@
MA.'L'8'@#"`"X&S!H.$#D(G@"B""X0R@CN$!H`K@!$")X`R0#N`+((+@Y+"=
MY0F0BN'A+8+@!$")X."0G>5A$:#AXDV$X`&@C.$#L(O@`Y")X`*@"N`.D(G@
M8B&@X0'@#.`.X(KA`J"!X0G@CN`$H`K@9)&@X>3MCN`"0`'@#,"+X`1`BN$)
MH(+A#,"$X.A`G>4.H`K@[LV,X`FP`N!NX:#A"["*X0-`A.`.H(GA`1"$X.Q`
MG>4,H`K@`1"+X/"PG>7L'8'@;,&@X0-`A.`"((3@#D`)X`1`BN$#H(O@`D"$
MX`P@CN'A383@`;`"X&$1H.$,(`[@"9"*X`(@B^'TH)WE`;",X0D@@N`$L`O@
M`9`,X`FPB^'XD)WEY"V"X`.@BN!D0:#A#N"*X`,PB>`.D(O@!."!X02@`>`"
MX`[@#,"#X`K@CN'6,0SC#,".X/S@G>5B.DSCXIV)X&(AH.$`L9WEZ<V,X`/@
MCN`!$([@`N`DX`G@+N!ID:#A#A"!X.SM@>`$$9WE`Z"+X`1`BN`,L9WE":`B
MX`R@*N!LP:#A`Q"!X`(@@>`,$"G@#A`AX`I`A.`!((+@"!&=Y>Y-A.!NX:#A
MY"V"X`.@@>!D$:#A":"*X`Z0+.`)0"3@!*"*X`-`B^`4L9WE#,"$X`%`+N`"
M0"3@XJV*X`1`C.`0P9WE8B&@X6J1H.'J383@`\",X`[@C.`"P"'@"L`LX`S`
MCN`#X(O@'+&=Y0$0CN`)X"+@!.`NX.3-C.`.$('@&.&=Y61!H.'L'8'@!*`I
MX`R@*N`#X([@;,&@X0+@CN`*H([@`R"+X`S@).`DL9WE"2""X`'@+N`.X(+@
M("&=Y>&MBN!A$:#AZNV.X`.0@N!J(:#A!)")X`%`+.`*0"3@!$")X`.0B^`L
ML9WE#,")X`*0(>`.D"G@[DV$X`G`C.`HD9WE;N&@X>3-C.`#H(G@9)&@X0&@
MBN`.$"+@!!`AX`-`B^`TL9WE`B"$X`E`+N`,0"3@`1"*X`0@@N`P09WE[!V!
MX&S!H.'A+8+@#*`IX`&@*N`#0(3@81&@X0Y`A.`*0(3@`^"+X`&@+.`\L9WE
M">".X`*@*N#B383@8I&@X0H@CN`XX9WEY"V"X`.@CN!DX:#A#*"*X`G`(>`$
MP"S@`T"+X$2QG>4!$(3@#D`IX`)`).`,P(K@!!"!X$!!G>7BS8S@8B&@X>P=
M@>`#H(3@;$&@X0F@BN`"D"[@"<`LX`.0B^!(L9WE#,"*X`[@B>!,H9WE!)`B
MX.'-C.`!D"G@81&@X0,PB^`)X([@"#"#X`&0).#L[8[@`C"#X!`@D.4,D"G@
M"9"#X&S!A^#N/8G@#N"&X`$0A>`$0(+@"$"`Z`0PG>4(P(#E#!"`Y1!`@.4`
M,)/E`P!:X08``!I5WXWBT$#-X=A@S>'0@<WAV*'-X2#0C>($\)WDD/3_ZZC$
M`0`H`0``"$`MY6``H..)2PKC!."-Y<U/3N.%]/_K`2,"X_[L#>-%)T;CNNA)
MXW;$!>/P$0[C%$"`Z#+`0>,`(*#CTA-,XPS`@.40$(#E%""`Y1@@@.5<((#E
M`$"=Y030C>($\)WD\$)MX0!0H.$!0*#A^&#-X1QP@.+P@<WA`I"@X8(AH.$8
MH(WE'."-Y10PD.4",)/@&""0Y0$0H"-<`)#E`!"@,P``4>,4,(7E`2""$JDN
M@N```%#C&""%Y14```I`@&#B!!"@X0@`6>$``(?@"8"@L0@@H.$Q]/_K7#"5
MY0,PB.!``%/C7#"%Y04```K00,WAV&#-X="!S>$8H)WE'-"-X@3PG>0%`*#A
M")!)X`A`A."W_/_K/P!9XQ@``-I`D$GB*6.@X0&`AN((@X3@!!"@X4`@A.('
M,*#A`$"1Y1`0@>(0,(/B#.`1Y0C`$>4$`!'E`@!1X1!``^4,X`/E",`#Y00`
M`^7S__\:`4"@X04`H.&?_/_K"`!4X>O__QH&DTG@!!"@X0<`H.$)(*#A`_3_
MZUR0A>74___J^$%MX0%`H.%_$.#C^&#-X0!0H.$0@(WE'("$XA3@C>748<3A
MUC'EYP$@@^(X`%+C`Q#(YP(`B.!&``#*."!BX@`0H./%\__K)SR@X2<8H.$F
M+*#A!`"@X50PQ.4F.*#A51#$Y5=PQ.4G=*#A6V#$Y29DH.%6<,3E6"#$Y5DP
MQ.5:8,3E=/S_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4
MY0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,TH.$&,,7E!#"4Y0<PQ>4+,-3E
M"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4Y0LPQ>4/,-3E###%Y;XPU.$-
M,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E$##%Y;(QU.$1,,7E$#"4Y2,T
MH.$2,,7E$#"4Y1,PQ>700,WAV&#-X1"`G>44X)WE&-"-XI#S_^I`(&+B`!"@
MXW[S_^L$`*#A._S_ZP@`H.$X(*#C`!"@XWCS_^NQ___J\$)MX710G^7X8,WA
M<&"?Y0!PH.'P@<WA`8"@X0*0H.$8H(WE!5"/X!S@C>4&8(_@!6!&X#WS_^M&
M8;#A"0``"@101>(`0*#C`4"$X@0PM>4)(*#A"!"@X0<`H.$S_R_A!`!6X??_
M_QK00,WAV&#-X="!S>$8H)WE'-"-X@3PG>10M`$`3+0!`![_+^$(,)_E`S"/
MX``PD^6P\__J6+8!``A`+>D(@+WH`0`"`'!E<FQX<VDN8P````!#04-(10``
M+@```"XN```E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O
M)6DO)7,`97AE`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E
M<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),
M24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!0
M05)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!
M4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`````,0```$Q$7TQ)0E)!4EE?4$%42`!365-4
M14T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(
M`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!
M4CHZ4&%C:V5R.CI615)324].`````#$N,#4W````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M
M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<```
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`(&R`8&PL*X'`````(*R`8&PL*D'
M`````(:R`8&PL*]_`````(:R`8&PL*L/`````**R`8&PL*\'`````."-_W^P
MJPB`B)#_?P$````0DO]_L+"N@`B3_W^PJP*`M)/_?["O!(#\E?]_L*\>@'"7
M_W^PJ1R`!)C_?XC__W\TF?]_C/__?TR:_W^0__]_Y)O_?["PJ(`XG/]_L*@!
M@*R<_W^$__]_F)W_?["PL("4G?]_@/__?R"@_W^PL*B`K*#_?["J`8!\HO]_
ML*@!@/BB_W^PL*B`%*/_?["L!8`<I/]_L*\\@+2J_W^PK`&`8*W_?["PJH#8
MK?]_KS\4@-RY_W^PL*B`-+K_?["PKH!DN_]_L+"L@-R\_W^PL*Z`7+W_?["P
ML(!LO?]_`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'P=```('0```0```%8#```!````80,`
M``$```!Q`P```0```'L#```!````CP,``!T````9!0``#````$06```-````
MM$D``!D```"0_0$`&P````0````:````E/T!`!P````$````!````+0!``#U
M_O]O^`0```4```#(#```!@```.@%```*````3@4```L````0````%0``````
M```#````P/X!``(```#H`0``%````!$````7````7!0``!$```!T$P``$@``
M`.@````3````"````!X````(````^___;P$```C^__]O]!(``/___V\$````
M\/__;Q82``#Z__]O$```````````````````````````````````````````
M``````````````"8_0$```````````!0%@``4!8``%`6``!0%@``4!8``%`6
M``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8`
M`%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``
M4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0
M%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6
M``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``4!8``%`6``!0%@``G$D`
M```````````````````````````````````````420``````````````````
M````````````````0!D````````$``(`"E!!4BYP;0H`````^$P``-1)````
M````]$H``/A*``#L3```/$H``/1,````````V$P``.!,`````````$T``$=#
M0SH@*%-54T4@3&EN=7@I(#<N-2XP`$$R````865A8FD``2@````%-RU!``8*
M!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R
M<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!
M4DTN97AT86(`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!
M4DTN871T<FEB=71E<P``````````````````````````````````````````
M``````````````L````!`````@```%0!``!4`0``&0```````````````0``
M```````3````!P````(```!P`0``<`$``"0```````````````0`````````
M)@````<````"````E`$``)0!```@```````````````$`````````#@````%
M`````@```+0!``"T`0``1`,```8`````````!`````0````T````]O__;P(`
M``#X!```^`0``/`````&``````````0````$````/@````L````"````Z`4`
M`.@%``#@!@``!P````,````$````$````$8````#`````@```,@,``#(#```
M3@4``````````````0````````!.````____;P(````6$@``%A(``-P````&
M``````````(````"````6P```/[__V\"````]!(``/02``"`````!P````0`
M```$`````````&H````)`````@```'03``!T$P``Z`````8`````````!```
M``@```!S````"0```$(```!<%```7!0``.@!```&````%P````0````(````
M?`````$````&````1!8``$06```,```````````````$`````````'<````!
M````!@```%`6``!0%@``\`(`````````````!`````0```""`````0````8`
M``!`&0``0!D``'0P``````````````0`````````B`````$````&````M$D`
M`+1)```(```````````````$`````````(X````!`````@```+Q)``"\20``
M:$$`````````````!`````````"6`````0````(````DBP``)(L``#P`````
M``````````0`````````H0````$``'""````8(L``&"+``#P````#@``````
M```$`````````*P````!`````@```%",``!0C```!```````````````!```
M``````"V````#@````,```"0_0$`D/T```0```````````````0````$````
MP@````\````#````E/T!`)3]```$```````````````$````!````,X````&
M`````P```)C]`0"8_0``*`$```<`````````!`````@```#7`````0````,`
M``#`_@$`P/X``$`!``````````````0````$````W`````$````#```````"
M`````0!(```````````````$`````````.(````(`````P```$@``@!(``$`
M%```````````````!`````````#G`````0```#``````````2``!`!@`````
M``````````$````!````\`````,``'```````````&```0`S````````````
M```!``````````$````#``````````````"3``$```$``````````````0``
%````````
